@@ -2,7 +2,7 @@ __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 __title__ = 'qq'
 __author__ = 'Foxwhite'
 __license__ = 'MIT'
-__version__ = '1.1.9'
+__version__ = '1.2.3'
 
 #  The MIT License (MIT)
 #  Copyright (c) 2021-present foxwhite25
@@ -25,30 +25,32 @@ __version__ = '1.1.9'
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 
-import logging
 from typing import NamedTuple, Literal
-from .client import *
-from .user import *
-from .channel import *
-from .guild import *
-from .flags import *
-from .member import *
-from .message import *
-from .asset import *
-from .role import *
-from .file import *
-from .colour import *
-from .object import *
+
 from . import utils, abc
-from .enum import *
-from .shard import *
-from .error import *
-from .embeds import *
-from .mention import *
-from .partial_emoji import *
-from .raw_models import *
-from .permissions import *
 from .api_permission import *
+from .asset import *
+from .channel import *
+from .client import *
+from .colour import *
+from .embeds import *
+from .enum import *
+from .error import *
+from .file import *
+from .flags import *
+from .guild import *
+from .member import *
+from .mention import *
+from .message import *
+from .object import *
+from .partial_emoji import *
+from .permissions import *
+from .raw_models import *
+from .reaction import *
+from .role import *
+from .schedule import *
+from .shard import *
+from .user import *
 
 
 class VersionInfo(NamedTuple):
@@ -59,4 +61,4 @@ class VersionInfo(NamedTuple):
     serial: int
 
 
-version_info: VersionInfo = VersionInfo(major=1, minor=1, micro=9, releaselevel='beta', serial=0)
+version_info: VersionInfo = VersionInfo(major=1, minor=2, micro=3, releaselevel='beta', serial=0)
