@@ -22,16 +22,14 @@
 from __future__ import annotations
 
 import asyncio
-import copy
 from datetime import datetime
-from typing import overload, Optional, Union, List, TYPE_CHECKING, TypeVar, Dict, Any, runtime_checkable, Protocol, \
-    Tuple
+from typing import (
+    overload, Optional, Union, List, TYPE_CHECKING, TypeVar, Dict, Any, runtime_checkable, Protocol, Tuple
+)
 
-from .asset import Asset
 from .enum import ChannelType
 from .error import InvalidArgument
 from .iterators import HistoryIterator
-from .mention import AllowedMentions
 from .utils import MISSING
 
 if TYPE_CHECKING:
@@ -41,7 +39,7 @@ if TYPE_CHECKING:
     from .channel import CategoryChannel, TextChannel, PartialMessageable, DMChannel
     from .guild import Guild
     from .state import ConnectionState
-    from .message import Message, MessageReference, PartialMessage, MessageAudit
+    from .message import Message, MessageReference, PartialMessage
     from .types.channel import (
         Channel as ChannelPayload,
     )
@@ -111,7 +109,7 @@ class Messageable:
             ark: Ark = ...,
             delete_after: float = ...,
             image: str = ...,
-            msg_id: Union[Message, MessageReference, PartialMessage]=...,
+            msg_id: Union[Message, MessageReference, PartialMessage] = ...,
             reference: Union[Message, MessageReference, PartialMessage] = ...,
             mention_author: Member = ...,
             direct=...,
@@ -175,7 +173,7 @@ class Messageable:
         Union[:class:`~qq.Message`, :class:`~qq.MessageAudit`]
             发送的消息。
         """
-
+        from .channel import TextChannel
         channel, direct = await self._get_channel()
         state = self._state
         content = str(content) if content is not None else None
@@ -212,8 +210,12 @@ class Messageable:
             return data['data']['message_audit']['audit_id']
 
         ret = state.create_message(channel=channel, data=data, direct=direct)
+        state.dispatch('message', ret)
+        state._messages.append(ret)
+        if channel and channel.__class__ in (TextChannel,):
+            channel.last_message_id = ret.id
         if delete_after is not None:
-            await ret.delete(delay=delete_after)
+            await ret.delete(delay=delete_after)  # type: ignore
         return ret
 
     async def fetch_message(self, id: int, /) -> Message:
