@@ -23,14 +23,14 @@ from __future__ import annotations
 
 import asyncio
 import datetime
-import time
-from typing import TYPE_CHECKING, Iterable, Optional, List, overload, Callable, TypeVar, Type, Tuple
+from typing import TYPE_CHECKING, Iterable, Optional, List, overload, Callable, TypeVar, Type, Tuple, Union
 
 from . import abc, utils
-from .error import ClientException
 from .enum import ChannelType, try_enum
+from .error import ClientException
 from .mixins import Hashable
 from .object import Object
+from .schedule import Schedule
 
 __all__ = (
     'TextChannel',
@@ -149,8 +149,8 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable):
     def _update(self, guild: Guild, data: TextChannelPayload) -> None:
         self.guild: Guild = guild
         self.name: str = data['name']
-        self.category_id: Optional[int] = int(data.get('parent_id'))
-        self.position: int = data['position']
+        self.category_id: Optional[int] = int(data.get('parent_id')) if 'parent_id' in data else self.category_id
+        self.position: int = data['position'] if 'position' in data else self.position
         self._type: int = data.get('type', self._type)
         self.private_type: int = data.get('private_type')
 
@@ -297,12 +297,13 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable):
             bulk: bool = True,
     ) -> List[Message]:
         """|coro|
-        清除符合谓词 ``check`` 给定标准的消息列表。
+        清除符合检查函数 ``check`` 给定标准的消息列表。
         如果未提供 ``check`` ，则所有消息都将被删除，一视同仁。
 
         Examples
         ---------
-        删除机器人的消息 ::
+        删除机器人的消息: ::
+
             def is_me(m):
                 return m.author == client.user
             deleted = await channel.purge(limit=100, check=is_me)
@@ -314,9 +315,9 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable):
             要搜索的消息数。这不是将被删除的消息数，尽管可以是。
         check: Callable[[:class:`Message`], :class:`bool`]
             用于检查是否应删除消息的功能。它必须将 Message 作为其唯一参数。
-        before: Optional[Union[:class:`abc.Snowflake`, :class:`datetime.datetime`]]
+        before: Optional[:class:`datetime.datetime`]
             与 :meth:`history` 中的 ``before`` 相同。
-        after: Optional[Union[:class:`abc.Snowflake`, :class:`datetime.datetime`]]
+        after: Optional[:class:`datetime.datetime`]
             与 :meth:`history` 中的 ``after`` 相同。
         around: Optional[Union[:class:`abc.Snowflake`, :class:`datetime.datetime`]]
             与 :meth:`history`中的 ``around`` 相同。
@@ -370,6 +371,26 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable):
 
         return ret
 
+    async def unpin(self, reason: Optional[str] = None):
+        """
+        删除所有此子频道的公告。
+
+        Parameters
+        -----------
+        reason: Optional[:class:`str`]
+            删除公告的原因。
+
+        Raises
+        -------
+        Forbidden
+            你没有足够权限删除公告。.
+        NotFound
+            消息或频道无法被找到，可能被删除了.
+        HTTPException
+            删除公告失败。
+        """
+        await self._state.http.channel_unpin_message(self.id, 'all', reason=reason)
+
 
 class VoiceChannel(abc.GuildChannel, Hashable):
     """表示 QQ 语音子频道。
@@ -664,6 +685,60 @@ class AppChannel(abc.GuildChannel, Hashable):
         joined = ' '.join('%s=%r' % t for t in attrs)
         return f'<{self.__class__.__name__} {joined}>'
 
+    async def create_schedule(
+            self,
+            name: str,
+            start: Union[datetime.datetime, float],
+            end: Union[datetime.datetime, float],
+            jump_channel: GuildChannelType,
+            remind_type: str,
+            description: Optional[str] = None,
+    ) -> Schedule:
+        """返回具有给定 path 和 method 的权限。
+
+        Parameters
+        -----------
+        name: :class:`str`
+            成员所属的频道。
+        description: Optional[:class:`str`]
+        start: Union[:class:`datetime.datetime`, :class:`float`]
+            日程开始的时间。
+        end: Union[:class:`datetime.datetime`, :class:`float`]
+            日程开始的时间。
+        jump_channel: :class:`GuildChannel`
+            日程开始的时间。
+        remind_type: :class:`str`
+            日程提醒类型。
+
+            +-----------+--------------+
+            | 提醒类型 id	  | 描述           |
+            +===========+==============+
+            | 0         | 不提醒          |
+            | 1         | 开始时提醒        |
+            | 2         | 开始前 5 分钟提醒   |
+            | 3         | 开始前 15 分钟提醒  |
+            | 4         | 开始前 30 分钟提醒  |
+            | 5         | 开始前 60 分钟提醒  |
+            +-----------+--------------+
+
+
+        Returns
+        --------
+        Optional[:class:`Schedule`]
+            Role 或如果未找到，则  ``None`` 。
+        """
+        schedule = await self._state.http.create_schedule(
+            channel_id=self.id,
+            name=name,
+            start_timestamp=start,
+            end_timestamp=end,
+            jump_channel_id=jump_channel.id,
+            remind_type=remind_type,
+            description=description
+        )
+
+        return Schedule(data=schedule, state=self._state, guild=self.guild, channel=self)
+
 
 class ThreadChannel(abc.GuildChannel, Hashable):
     """表示 QQ 论坛子频道。
