@@ -24,7 +24,6 @@ __all__ = (
     'Client',
 )
 
-
 import asyncio
 import logging
 import signal
@@ -38,13 +37,14 @@ import aiohttp
 from . import utils
 from .backoff import ExponentialBackoff
 from .error import HTTPException, GatewayNotFound, ConnectionClosed
-from .state import ConnectionState
 from .gateway import QQWebSocket, ReconnectWebSocket
 from .guild import Guild
 from .http import HTTPClient
 from .iterators import GuildIterator
-from .user import ClientUser, User
 from .nest_asyncio import apply
+from .state import ConnectionState
+from .user import ClientUser, User
+
 if TYPE_CHECKING:
     from .channel import DMChannel
     from .abc import GuildChannel
@@ -678,7 +678,7 @@ class Client:
         event: :class:`str`
             事件名称，类似于 :ref:`事件指南 <qq-api-events>`，但没有 ``on_`` 前缀，用于等待。
         check: Optional[Callable[..., :class:`bool`]]
-            检查等待什么的谓词。 参数必须满足正在等待的事件的参数。
+            检查等待什么的检查函数。 参数必须满足正在等待的事件的参数。
         timeout: Optional[:class:`float`]
             在超时和引发 :exc:`asyncio.TimeoutError` 之前等待的秒数。
 
@@ -762,5 +762,3 @@ class Client:
 
         data = await state.http.start_private_message(user.id, guild.id)
         return state.add_dm_channel(data, user)
-
-
