@@ -32,7 +32,7 @@ from collections import namedtuple
 import aiohttp
 
 from qq import utils
-from qq.error import ConnectionClosed, InvalidArgument
+from qq.error import ConnectionClosed
 
 EventListener = namedtuple('EventListener', 'predicate event result future')
 _log = logging.getLogger(__name__)
@@ -280,7 +280,7 @@ class QQWebSocket:
         return ws
 
     def wait_for(self, event, predicate, result=None):
-        """等待满足谓词的 DISPATCH 事件。
+        """等待满足检查函数的 DISPATCH 事件。
 
         Parameters
         -----------
@@ -334,7 +334,7 @@ class QQWebSocket:
             'd': {
                 'seq': self.sequence,
                 'session_id': self.session_id,
-                'token': 'Bot '+self.token
+                'token': 'Bot ' + self.token
             }
         }
 
@@ -558,4 +558,4 @@ class QQWebSocket:
             self._keep_alive = None
 
         self._close_code = code
-        await self.socket.close(code=code)
\ No newline at end of file
+        await self.socket.close(code=code)
