@@ -36,20 +36,16 @@ from typing import (
 )
 
 from . import utils, abc
-from .enum import ChannelType
 from .api_permission import Permission
-from .role import Role
-from .member import Member
-from .error import InvalidData, HTTPException
-from .colour import Colour
-from .error import InvalidArgument, ClientException
 from .channel import *
 from .channel import _guild_channel_factory, _channel_factory
-from .mixins import Hashable
-from .user import User
+from .colour import Colour
+from .enum import ChannelType
+from .error import ClientException, InvalidData, HTTPException
 from .iterators import MemberIterator
-from .asset import Asset
-from .file import File
+from .member import Member
+from .mixins import Hashable
+from .role import Role
 
 MISSING = utils.MISSING
 
@@ -259,7 +255,7 @@ class Guild(Hashable):
     @property
     def large(self) -> bool:
         """:class:`bool`: 指示频道是否是 ``大型`` 频道。
-        大型公会被定义为拥有超过 ``large_threshold`` 计数的成员，本库的最大值设置为 250。
+        大型频道被定义为拥有超过 ``large_threshold`` 计数的成员，本库的最大值设置为 250。
         """
         if self._large is None:
             try:
@@ -313,6 +309,14 @@ class Guild(Hashable):
         r.sort(key=lambda c: (c.position, c.id))
         return r
 
+    @property
+    def app_channels(self) -> List[AppChannel]:
+        """List[:class:`AppChannel`]: 属于该频道的应用频道列表。这是按位置排序的，从上到下按 UI 顺序排列。
+        """
+        r = [ch for ch in self._channels.values() if isinstance(ch, AppChannel)]
+        r.sort(key=lambda c: (c.position, c.id))
+        return r
+
     @property
     def categories(self) -> List[CategoryChannel]:
         """List[:class:`CategoryChannel`]: 属于该频道的类别列表。这是按位置排序的，从上到下按 UI 顺序排列。
@@ -946,7 +950,7 @@ class Guild(Hashable):
 
     async def kick(self, user: Member, *, reason: Optional[str] = None) -> None:
         """|coro|
-        将一个用户踢出公会。
+        将一个用户踢出频道。
 
         Parameters
         -----------
@@ -962,7 +966,62 @@ class Guild(Hashable):
         HTTPException
             踢出失败。
         """
-        await self._state.http.kick(user.id, self.id, reason=reason)
+        await self._state.http.kick(user.id, self.id, add_blacklist=False, reason=reason)
+
+    async def ban(
+            self,
+            user: Member,
+            *,
+            reason: Optional[str] = None,
+            delete_message_days: Literal[0, 1, 2, 3, 4, 5, 6, 7] = 1,
+    ) -> None:
+        """|coro|
+        封禁频道用户。
+
+        Parameters
+        -----------
+        user: :class:`qq.Member`
+            要封禁的用户
+        delete_message_days: :class:`int`
+            要删除的消息的天数
+            在频道中。 最小值为 0，最大值为 7。
+        reason: Optional[:class:`str`]
+            该用户被封禁的原因
+
+        Raises
+        -------
+        Forbidden
+            你没有权限封禁用户。
+        HTTPException
+            封禁失败。
+        """
+        await self._state.http.kick(user.id, self.id, add_blacklist=True, reason=reason)
+
+    async def unmute_member(
+            self,
+            user: Member,
+            *,
+            reason: Optional[str] = None,
+    ):
+        """|coro|
+        频道指定成员解除禁言。
+
+        Parameters
+        -----------
+        user: :class:`qq.Member`
+            这个频道解除禁言的用户。
+        reason: Optional[:class:`str`]
+            解除禁言的原因。
+
+        Raises
+        -------
+        Forbidden
+            你没有适当的权限。
+        HTTPException
+            解除禁言失败。
+        """
+
+        await self.mute_member(user, duration=0, reason=reason)
 
     async def mute_member(
             self,
@@ -973,11 +1032,10 @@ class Guild(Hashable):
     ) -> None:
         """|coro|
         频道指定成员禁言。
-        需要使用的token对应的用户(或机器人)具备管理员权限。
 
         Parameters
         -----------
-        user: :class:`qq.User`
+        user: :class:`qq.Member`
             这个频道禁言的用户。
         duration: Union[:class:`datetime.datetime`, :class:`int`]
             禁言的时间，可以是结束时间的一个 :class:`datetime.datetime` ， 也可以是持续的秒数。
@@ -1037,3 +1095,22 @@ class Guild(Hashable):
         .. versionadded:: 1.1.0"""
         return [m for m in self._members.values() if not m.bot]
 
+    async def unpin(self, reason: Optional[str] = None):
+        """
+        删除所有此频道的全局公告。
+
+        Parameters
+        -----------
+        reason: Optional[:class:`str`]
+            删除公告的原因。
+
+        Raises
+        -------
+        Forbidden
+            你没有足够权限删除公告。.
+        NotFound
+            消息或频道无法被找到，可能被删除了.
+        HTTPException
+            删除公告失败。
+        """
+        await self._state.http.global_unpin_message(self.id, 'all', reason=reason)
