@@ -22,35 +22,30 @@
 from __future__ import annotations
 
 import asyncio
-import concurrent.futures
 import datetime
-import json
 import logging
 import sys
 import weakref
 from types import TracebackType
-from typing import ClassVar, Any, Optional, Sequence, Iterable, Dict, Union, TypeVar, Type, Coroutine, List, Tuple
+from typing import ClassVar, Any, Optional, Iterable, Dict, Union, TypeVar, Type, Coroutine, List, Tuple
 from urllib.parse import quote as _uriquote
+
 import aiohttp
-import requests
 
 from . import __version__, utils
-from .role import Role
 from .embeds import Ark, Embed
-from .types.member import MemberWithUser as MemberPayload
 from .error import HTTPException, Forbidden, NotFound, QQServerError, LoginFailure, GatewayNotFound
 from .gateway import QQClientWebSocketResponse
-from .types.message import Message
+from .role import Role
 from .types import user, guild, message, channel, member
 from .types.embed import Ark as ArkPayload, Embed as EmbedPayload
-from .utils import MISSING
-from .types.channel import Channel as ChannelPayload
-from .types.role import Role as RolePayload
+from .types.message import Message
 from .types.permission import (
     Permission as PermissionPayload,
-    PermissionDemand as PermissionDemandPayload,
-    PermissionDemandIdentify as PermissionDemandIdentifyPayload
+    PermissionDemand as PermissionDemandPayload
 )
+from .types.schedule import Schedule as SchedulePayload
+from .utils import MISSING
 
 T = TypeVar('T')
 BE = TypeVar('BE', bound=BaseException)
@@ -128,16 +123,20 @@ class HTTPClient:
             loop: Optional[asyncio.AbstractEventLoop] = None,
             unsync_clock: bool = True,
     ) -> None:
+        self.loop: asyncio.AbstractEventLoop = asyncio.get_event_loop() if loop is None else loop
+        self.connector = connector
+        self.__session: aiohttp.ClientSession = MISSING  # filled in static_login
         self._locks: weakref.WeakValueDictionary = weakref.WeakValueDictionary()
-        user_agent = 'QQ Bot (https://github.com/foxwhite25/qq.py {0}) Python/{1[0]}.{1[1]} aiohttp/{2}'
-        self.user_agent: str = user_agent.format(__version__, sys.version_info, aiohttp.__version__)
-        self.token: Optional[str] = None
-        self.proxy: Optional[str] = proxy
-        self.proxy_auth: Optional[aiohttp.BasicAuth] = proxy_auth
         self._global_over: asyncio.Event = asyncio.Event()
         self._global_over.set()
-        self.__session: aiohttp.ClientSession = MISSING
-        self.connector = connector
+        self.token: Optional[str] = None
+        self.bot_token: bool = False
+        self.proxy: Optional[str] = proxy
+        self.proxy_auth: Optional[aiohttp.BasicAuth] = proxy_auth
+        self.use_clock: bool = not unsync_clock
+
+        user_agent = "QQBot (https://github.com/foxwhite25/qq.py {0}) Python/{1[0]}.{1[1]} aiohttp/{2}"
+        self.user_agent: str = user_agent.format(__version__, sys.version_info, aiohttp.__version__)
 
     async def request(
             self,
@@ -215,7 +214,7 @@ class HTTPClient:
                             return data
 
                         # we've received a 500, 502, or 504, unconditional retry
-                        # if response.status in {500, 502, 504}:
+                        # if response.status in {500}:
                         #     await asyncio.sleep(1 + tries * 2)
                         #     continue
 
@@ -236,6 +235,11 @@ class HTTPClient:
                         await asyncio.sleep(1 + tries * 2)
                         continue
                     raise
+                except QQServerError as e:
+                    if e.code in (620006, ):
+                        await asyncio.sleep(1 + tries * 2)
+                        continue
+                    raise e
 
                 if response is not None:
                     # We've run out of retries, raise.
@@ -279,36 +283,6 @@ class HTTPClient:
 
         return self.request(Route('GET', '/users/@me/guilds'), params=params)
 
-    def sync_get_bot_member(self, guild_id: int, user_id: int) -> MemberPayload:
-        headers: Dict[str, str] = {
-            'User-Agent': self.user_agent,
-        }
-        if self.token is not None:
-            headers['Authorization'] = 'Bot ' + self.token
-        rsp = requests.get(f'https://api.sgroup.qq.com/guilds/{guild_id}/members/{user_id}', headers=headers)
-        _log.debug('GET %s 与 %s 已返回 %s', f'https://api.sgroup.qq.com/guilds/{guild_id}/members/{user_id}', rsp.json(),
-                   rsp.status_code)
-        if rsp.status_code == 200:
-            return rsp.json()
-
-    def sync_guild_channels_roles(self, guild_id: int) -> Tuple[
-        List[ChannelPayload], List[RolePayload], List[MemberPayload]]:
-        headers: Dict[str, str] = {
-            'User-Agent': self.user_agent,
-        }
-        if self.token is not None:
-            headers['Authorization'] = 'Bot ' + self.token
-        result = []
-        for n in ['channels', 'roles', 'members']:
-            rsp = requests.get(f'https://api.sgroup.qq.com/guilds/{guild_id}/{n}', headers=headers)
-            _log.debug('GET %s 与 %s 已返回 %s', f'https://api.sgroup.qq.com/guilds/{guild_id}/{n}', rsp.json(),
-                       rsp.status_code)
-            if rsp.status_code == 200:
-                result.append(rsp.json())
-            else:
-                result.append([])
-        return tuple(result)
-
     def get_guild(self, guild_id: int) -> Response[guild.Guild]:
         return self.request(Route('GET', '/guilds/{guild_id}', guild_id=guild_id))
 
@@ -561,37 +535,78 @@ class HTTPClient:
         r = Route('GET', '/channels/{channel_id}', channel_id=channel_id)
         return self.request(r)
 
-    def kick(self, user_id: int, guild_id: int, reason: Optional[str] = None) -> Response[None]:
+    def kick(self, user_id: int, guild_id: int, add_blacklist: bool, reason: Optional[str] = None) -> Response[None]:
         r = Route('DELETE', '/guilds/{guild_id}/members/{user_id}', guild_id=guild_id, user_id=user_id)
+        payload: Dict[str, Any] = {
+            'add_blacklist': add_blacklist,
+        }
         if reason:
             # thanks aiohttp
             r.url = f'{r.url}?reason={_uriquote(reason)}'
 
-        return self.request(r)
+        return self.request(r, json=payload)
+
+    def create_schedule(
+            self,
+            channel_id: int,
+            name: str,
+            start_timestamp: Union[datetime.datetime, float],
+            end_timestamp: Union[datetime.datetime, float],
+            jump_channel_id: int,
+            remind_type: str,
+            description: Optional[str],
+            reason: Optional[str] = None
+    ) -> Response[SchedulePayload]:
+        payload: Dict[str, Any] = {
+            "schedule": {
+                "name": name,
+                "start_timestamp": str(int(start_timestamp * 1000)) if isinstance(start_timestamp, float)
+                else str(int(start_timestamp.timestamp() * 1000)),
+                "end_timestamp": str(int(end_timestamp * 1000)) if isinstance(end_timestamp, float)
+                else str(int(end_timestamp.timestamp() * 1000)),
+                "jump_channel_id": str(jump_channel_id),
+                "remind_type": remind_type
+            }
+        }
+
+        if description is not None:
+            payload["schedule"]["description"] = description
+
+        r = Route('POST', '/channels/{channel_id}/schedules', channel_id=channel_id)
+        return self.request(r, json=payload, reason=reason)
+
+    def remove_schedule(self, channel_id: int, schedule_id: int, reason: Optional[str] = None) -> Response[None]:
+        r = Route(
+            'DELEtE', '/channels/{channel_id}/schedules/{schedule_id}',
+            channel_id=channel_id,
+            schedule_id=schedule_id
+        )
+
+        return self.request(r, reason=reason)
 
     def mute_member(
-            self, user_id: int, guild_id: int, duration: Union[datetime.datetime, int], reason: str
+            self, user_id: int, guild_id: int, duration: Union[datetime.datetime, int], reason: Optional[str] = None
     ) -> Response[None]:
-        params: Dict[str, Any] = {}
+        payload: Dict[str, Any] = {}
         if isinstance(duration, datetime.datetime):
-            params['mute_end_timestamp'] = str(int(duration.timestamp() * 1000))
+            payload['mute_end_timestamp'] = str(int(duration.timestamp() * 1000))
         else:
-            params['mute_seconds'] = str(duration)
+            payload['mute_seconds'] = str(duration)
 
         r = Route('PATCH', '/guilds/{guild_id}/members/{user_id}/mute', guild_id=guild_id, user_id=user_id)
-        return self.request(r, json=params, reason=reason)
+        return self.request(r, json=payload, reason=reason)
 
     def mute_guild(
-            self, guild_id: int, duration: Union[datetime.datetime, int], reason: str
+            self, guild_id: int, duration: Union[datetime.datetime, int], reason: Optional[str] = None
     ) -> Response[None]:
-        params: Dict[str, Any] = {}
+        payload: Dict[str, Any] = {}
         if isinstance(duration, datetime.datetime):
-            params['mute_end_timestamp'] = str(int(duration.timestamp() * 1000))
+            payload['mute_end_timestamp'] = str(int(duration.timestamp() * 1000))
         else:
-            params['mute_seconds'] = str(duration)
+            payload['mute_seconds'] = str(duration)
 
         r = Route('PATCH', '/guilds/{guild_id}/mute', guild_id=guild_id)
-        return self.request(r, json=params, reason=reason)
+        return self.request(r, json=payload, reason=reason)
 
     def delete_message(
             self, channel_id: int, message_id: str, *, reason: Optional[str] = None
@@ -643,9 +658,94 @@ class HTTPClient:
     ) -> Response[PermissionDemandPayload]:
 
         payload: Dict[str, Any] = {
-            "channel_id": channel_id,
+            "channel_id": str(channel_id),
             "api_identify": {"path": path, "method": method},
             "desc": desc
         }
 
         return self.request(Route('POST', '/guilds/{guild_id}/api_permission/demand', guild_id=guild_id), json=payload)
+
+    def global_pin_message(
+            self,
+            guild_id: int,
+            channel_id: Optional[int] = None,
+            message_id: Optional[str] = None,
+            announces_type: Optional[int] = None,
+            recommend_channels: Optional[Dict[int, str]] = None,
+            reason: Optional[str] = None
+    ):
+        r = Route(
+            'POST',
+            '/guilds/{guild_id}/announces',
+            guild_id=guild_id,
+        )
+        if recommend_channels:
+            recommend_channels: List[Dict[str, str]] = [
+                {
+                    'channel_id': str(m),
+                    'introduce': n
+                } for m, n in recommend_channels.items()
+            ]
+        payload: Dict[str, Any] = {}
+        if channel_id is not None:
+            payload['channel_id'] = channel_id
+        if message_id is not None:
+            payload['message_id'] = message_id
+        if announces_type is not None:
+            payload['announces_types'] = announces_type
+        if recommend_channels is not None:
+            payload['recommend_channels'] = recommend_channels
+        return self.request(r, json=payload, reason=reason)
+
+    def global_unpin_message(self, guild_id: int, message_id: str, reason: Optional[str] = None):
+        r = Route(
+            'DELETE',
+            '/guilds/{guild_id}/announces/{message_id}',
+            guild_id=guild_id,
+            message_id=message_id
+        )
+        return self.request(r, reason=reason)
+
+    def channel_pin_message(self, channel_id: int, message_id: str, reason: Optional[str] = None):
+        r = Route(
+            'POST',
+            '/channels/{channel_id}/pins/{message_id}',
+            channel_id=channel_id,
+            message_id=message_id,
+        )
+        return self.request(r, reason=reason)
+
+    def channel_unpin_message(self, channel_id: int, message_id: str, reason: Optional[str] = None):
+        r = Route(
+            'DELETE',
+            '/channels/{channel_id}/pins/{message_id}',
+            channel_id=channel_id,
+            message_id=message_id
+        )
+        return self.request(r, reason=reason)
+
+    def add_reaction(
+            self, channel_id: int, message_id: str, custom: bool, id: int
+    ) -> Response[None]:
+        r = Route(
+            'PUT',
+            '/channels/{channel_id}/messages/{message_id}/reactions/{type}/{id}',
+            channel_id=channel_id,
+            message_id=message_id,
+            type=1 if custom else 2,
+            id=id
+        )
+        return self.request(r)
+
+    def remove_reaction(
+            self, channel_id: int, message_id: str, custom: bool, id: int
+    ) -> Response[None]:
+        r = Route(
+            'DELETE',
+            '/channels/{channel_id}/messages/{message_id}/reactions/{emoji}/{member_id}',
+            channel_id=channel_id,
+            message_id=message_id,
+            type=1 if custom else 2,
+            id=id
+        )
+        return self.request(r)
