@@ -36,25 +36,25 @@ import datetime
 import io
 import re
 from os import PathLike
-from typing import Union, Optional, TYPE_CHECKING, ClassVar, Tuple, List, Callable, overload, Any, Type, TypeVar
+from typing import Union, Optional, TYPE_CHECKING, ClassVar, Tuple, List, Callable, Any, Type, TypeVar
 
 from . import utils
-from .object import Object
-from .error import HTTPException
+from .embeds import Embed
+from .error import HTTPException, InvalidArgument
 from .file import File
+from .guild import Guild
 from .member import Member
 from .mixins import Hashable
+from .object import Object
+from .partial_emoji import PartialEmoji
+from .reaction import Reaction
 from .role import Role
 from .utils import escape_mentions
-from .guild import Guild
-from .partial_emoji import PartialEmoji
-from .embeds import Embed
-from .reaction import Reaction
 
 if TYPE_CHECKING:
     from .state import ConnectionState
     from .abc import GuildChannel, PartialMessageableChannel, MessageableChannel
-    from .channel import TextChannel, DMChannel
+    from .channel import TextChannel
     from .enum import ChannelType
     from .types.message import (
         Attachment as AttachmentPayload,
@@ -80,6 +80,20 @@ __all__ = (
 )
 
 
+def convert_emoji_reaction(emoji):
+    if isinstance(emoji, Reaction):
+        emoji = emoji.emoji
+
+    if isinstance(emoji, PartialEmoji):
+        return emoji._as_reaction()
+    if isinstance(emoji, str):
+        # Reactions can be in :name:id format, but not <:name:id>.
+        # No existing emojis have <> in them, so this should be okay.
+        return PartialEmoji.from_str(emoji)._as_reaction()
+
+    raise InvalidArgument(f'emoji 参数必须是 str、Emoji 或 Reaction 而不是 {emoji.__class__.__name__}。')
+
+
 class MessageAudit:
     """表示消息审核情况。
 
@@ -713,7 +727,7 @@ class Message(Hashable):
 
         if reaction is None:
             # already removed?
-            raise ValueError('Emoji already removed?')
+            raise ValueError('表情符号已被删除？')
 
         # if reaction isn't in the list, we crash. This means discord
         # sent bad data, or we stored improperly
@@ -920,6 +934,142 @@ class Message(Hashable):
 
         return data
 
+    async def global_pin(self, *, reason: Optional[str] = None) -> None:
+        """|coro|
+        把这条消息设为全局公告。
+
+        Parameters
+        -----------
+        reason: Optional[:class:`str`]
+            设为公告的原因。
+
+        Raises
+        -------
+        Forbidden
+            你没有足够权限设置公告。
+        NotFound
+            消息或频道无法被找到，可能被删除了
+        HTTPException
+            设置公告失败.
+        """
+
+        await self._state.http.global_pin_message(
+            guild_id=self.guild.id, channel_id=self.channel.id, message_id=self.id, reason=reason
+        )
+
+    async def global_unpin(self, *, reason: Optional[str] = None) -> None:
+        """|coro|
+        删除这条消息的全局公告。
+
+        Parameters
+        -----------
+        reason: Optional[:class:`str`]
+            删除公告的原因。
+
+        Raises
+        -------
+        Forbidden
+            你没有足够权限删除公告。.
+        NotFound
+            消息或频道无法被找到，可能被删除了.
+        HTTPException
+            删除公告失败。
+        """
+
+        await self._state.http.global_unpin_message(self.guild.id, self.channel.id, self.id, reason=reason)
+
+    async def channel_pin(self, *, reason: Optional[str] = None) -> None:
+        """|coro|
+        把这条消息设为子频道公告。
+
+        Parameters
+        -----------
+        reason: Optional[:class:`str`]
+            设为公告的原因。
+
+        Raises
+        -------
+        Forbidden
+            你没有足够权限设置公告。
+        NotFound
+            消息或频道无法被找到，可能被删除了
+        HTTPException
+            设置公告失败.
+        """
+
+        await self._state.http.channel_pin_message(self.channel.id, self.id, reason=reason)
+
+    async def channel_unpin(self, *, reason: Optional[str] = None) -> None:
+        """|coro|
+        删除这条消息的子频道公告。
+
+        Parameters
+        -----------
+        reason: Optional[:class:`str`]
+            删除公告的原因。
+
+        Raises
+        -------
+        Forbidden
+            你没有足够权限删除公告。.
+        NotFound
+            消息或频道无法被找到，可能被删除了.
+        HTTPException
+            删除公告失败。
+        """
+
+        await self._state.http.channel_unpin_message(self.channel.id, self.id, reason=reason)
+
+    async def add_reaction(self, emoji: EmojiInputType) -> None:
+        """|coro|
+        向消息添加表态。
+        表情符号可能是 unicode 表情符号或自定义 :class:`PartialEmoji` 。
+
+        Parameters
+        ------------
+        emoji: Union[:class:`Reaction`, :class:`PartialEmoji`, :class:`str`]
+            要表态的 emoji。
+
+        Raises
+        --------
+        HTTPException
+            添加 emoji 失败。
+        Forbidden
+            你没有对消息做出反应的适当权限。
+        NotFound
+            找不到你指定的表情符号。
+        InvalidArgument
+            表情符号参数无效。
+        """
+
+        custom, emoji = convert_emoji_reaction(emoji)
+        await self._state.http.add_reaction(self.channel.id, self.id, custom, emoji)
+
+    async def remove_reaction(self, emoji: Union[EmojiInputType, Reaction]) -> None:
+        """|coro|
+        删除自己的表态。
+        表情符号可能是 unicode 表情符号或自定义 :class:`PartialEmoji` 。
+
+        Parameters
+        ------------
+        emoji: Union[:class:`Reaction`, :class:`PartialEmoji`, :class:`str`]
+            要删除表态的 emoji。
+
+        Raises
+        --------
+        HTTPException
+            删除 emoji 失败。
+        Forbidden
+            你没有删除消息表态的适当权限。
+        NotFound
+            找不到你指定的表情符号。
+        InvalidArgument
+            表情符号参数无效。
+        """
+
+        custom, emoji = convert_emoji_reaction(emoji)
+        await self._state.http.remove_reaction(self.channel.id, self.id, custom, emoji)
+
 
 class PartialMessage(Hashable):
     """当仅存在消息和通道 ID 时，只使用部分消息以帮助处理消息。
