@@ -35,14 +35,14 @@ from . import utils
 from .audio import AudioAction
 from .channel import PartialMessageable, TextChannel, _channel_factory, DMChannel
 from .flags import Intents
+from .guild import Guild
+from .member import Member
 from .mention import AllowedMentions
+from .message import Message, MessageAudit
 from .object import Object
 from .partial_emoji import PartialEmoji
 from .raw_models import RawReactionActionEvent, RawReactionClearEvent, RawReactionClearEmojiEvent
 from .user import User, ClientUser
-from .guild import Guild
-from .message import Message, MessageAudit
-from .member import Member
 
 if TYPE_CHECKING:
     from .message import MessageableChannel
@@ -275,6 +275,7 @@ class ConnectionState:
 
     def _get_guild(self, guild_id: Optional[int]) -> Optional[Guild]:
         # the keys of self._guilds are ints
+        guild_id = int(guild_id)
         return self._guilds.get(guild_id)  # type: ignore
 
     def _add_guild(self, guild: Guild) -> None:
@@ -284,7 +285,7 @@ class ConnectionState:
         self._guilds.pop(guild.id, None)
         del guild
 
-    def _get_message(self, msg_id: Optional[int]) -> Optional[Message]:
+    def _get_message(self, msg_id: Optional[str]) -> Optional[Message]:
         return utils.find(lambda m: m.id == msg_id, reversed(self._messages)) if self._messages else None
 
     def _add_guild_from_data(self, data: GuildPayload) -> Guild:
@@ -387,7 +388,6 @@ class ConnectionState:
             if recipient is not None:
                 self._private_channels_by_user.pop(recipient.id, None)
 
-
     async def _delay_ready(self) -> None:
         try:
             states = []
@@ -498,6 +498,8 @@ class ConnectionState:
     def parse_channel_update(self, data) -> None:
         channel_id = int(data['id'])
         guild_id = data.get('guild_id')
+        if guild_id.isnumeric():
+            guild_id = int(guild_id)
         guild = self._get_guild(guild_id)
         if guild is not None:
             channel = guild.get_channel(channel_id)
@@ -708,7 +710,7 @@ class ConnectionState:
         self.dispatch('raw_reaction_add', raw)
 
         # rich interface here
-        message = self._get_message(raw.message_id)
+        message = self._get_message(raw.id)
         if message is not None:
             emoji = self._upgrade_partial_emoji(emoji)
             reaction = message._add_reaction(data, emoji, raw.user_id)
@@ -721,7 +723,7 @@ class ConnectionState:
         raw = RawReactionClearEvent(data)
         self.dispatch('raw_reaction_clear', raw)
 
-        message = self._get_message(raw.message_id)
+        message = self._get_message(raw.id)
         if message is not None:
             old_reactions = message.reactions.copy()
             message.reactions.clear()
@@ -734,7 +736,7 @@ class ConnectionState:
         raw = RawReactionActionEvent(data, emoji, 'REACTION_REMOVE')
         self.dispatch('raw_reaction_remove', raw)
 
-        message = self._get_message(raw.message_id)
+        message = self._get_message(raw.id)
         if message is not None:
             emoji = self._upgrade_partial_emoji(emoji)
             try:
@@ -753,7 +755,7 @@ class ConnectionState:
         raw = RawReactionClearEmojiEvent(data, emoji)
         self.dispatch('raw_reaction_clear_emoji', raw)
 
-        message = self._get_message(raw.message_id)
+        message = self._get_message(raw.id)
         if message is not None:
             try:
                 reaction = message._clear_emoji(emoji)
