@@ -19,7 +19,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 
-from typing import Literal, TypedDict, Optional, Union, List
+from typing import Literal, TypedDict, Optional, Union
 
 from .user import PartialUser
 
