@@ -24,7 +24,7 @@ from __future__ import annotations
 from typing import TypedDict
 
 
-class Role(TypedDict):
+class Role(TypedDict, total=False):
     id: str
     name: str
     color: int
